ERMLP
=====

.. currentmodule:: pykeen.models

.. autoclass:: ERMLP
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ERMLP.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
